@@ -190,7 +190,7 @@ class NetworkxDual(init_crystal.NetworkxCrystal):
 
             for idx_e, e in enumerate(K[i].edges()):
                 opt = {
-                'slope': [K[i].nodes[e[0]]['pos'], K[i].nodes[e[1]]['pos']],
+                # 'slope': [K[i].nodes[e[0]]['pos'], K[i].nodes[e[1]]['pos']],
                 'label': K[i].edges[e]['label']
                 }
                 v, u = dict_P[i][0][e[0]], dict_P[i][0][e[1]]
@@ -245,9 +245,9 @@ class NetworkxDual(init_crystal.NetworkxCrystal):
         adj = []
 
         for i, e in enumerate(G.edges()):
-            a = np.add(G.edges[e]['slope'][0], G.edges[e]['slope'][1])
+            a = np.add(G.nodes[e[0]]['pos'], G.nodes[e[1]]['pos'])
             for j, f in enumerate(H.edges()):
-                b = np.add(H.edges[f]['slope'][0], H.edges[f]['slope'][1])
+                b = np.add(H.nodes[f[0]]['pos'], H.nodes[f[1]]['pos'])
                 c = np.subtract(a, b)
                 if np.dot(c, c) == 14.:
                     adj.append([G.edges[e]['label'], H.edges[f]['label']])
@@ -344,7 +344,7 @@ class NetworkxDualSimple(NetworkxDual):
             for j, m in enumerate(list_p[(i+1):]):
                 dist = np.linalg.norm(n-m)
                 if dist == self.lattice_constant:
-                    G.add_edge(i, (i+1)+j, slope=(n, m), label=counter_e)
+                    G.add_edge(i, (i+1)+j, label=counter_e)
                     counter_e += 1
 
         return G, H
@@ -386,7 +386,7 @@ class NetworkxDualSimple(NetworkxDual):
 
                 if not H.has_edge(*E2):
                     options = {
-                    'slope': (V.vertices[e1], V.vertices[e2]),
+                    # 'slope': (V.vertices[e1], V.vertices[e2]),
                     'label': counter_e
                     }
                     H.add_edge(*E2, **options)
@@ -504,7 +504,7 @@ class NetworkxDualDiamond(NetworkxDual):
 
                 dist = np.linalg.norm(np.subtract(n, m))
                 if dist == self.lattice_constant:
-                    G.add_edge(i, (i+1)+j, slope=(n, m), label=counter_e)
+                    G.add_edge(i, (i+1)+j, label=counter_e)
                     counter_e += 1
 
         return G
@@ -654,7 +654,7 @@ class NetworkxDualLaves(NetworkxDual):
 
                 if dist == self.lattice_constant:
                     options = {
-                    'slope': (G_aux.nodes[n]['pos'], G_aux.nodes[m]['pos']),
+                    # 'slope': (G_aux.nodes[n]['pos'], G_aux.nodes[m]['pos']),
                     'label': counter_e
                     }
                     G.add_edge(n, m, **options)
